<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>NetFileChooseEdit</name>
    <message>
        <source>All files (*)</source>
        <translation>Alle Dateien (*)</translation>
    </message>
</context>
<context>
    <name>NetPasswordEdit</name>
    <message>
        <source>Required</source>
        <translation>Erforderlich</translation>
    </message>
</context>
<context>
    <name>PageAirplane</name>
    <message>
        <source>Airplane mode</source>
        <translation>Flugmodus</translation>
    </message>
    <message>
        <source>Stop wireless communication</source>
        <translation>Drahtloskommunikation stoppen</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation>Das Einschalten des Flugmodus beendet die WLAN-Verbindung, Persönlichen Hotspot und  Bluetooth</translation>
    </message>
</context>
<context>
    <name>PageAppProxy</name>
    <message>
        <source>Application Proxy</source>
        <translation>Anwendungs-Proxy</translation>
    </message>
    <message>
        <source>Set up proxy servers</source>
        <translation>Proxy-Server einrichten</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Proxy-Typ</translation>
    </message>
    <message>
        <source>http</source>
        <translation>http</translation>
    </message>
    <message>
        <source>socks4</source>
        <translation>socks4</translation>
    </message>
    <message>
        <source>socks5</source>
        <translation>socks5</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP-Adresse</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Erforderlich</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Ungültige IP-Adresse</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Ungültiger Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Optional</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>&quot;Proxy benutzen&quot; anklicken im Anwendungs-Kontextmenü im Starter nach der Konfiguration</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
</context>
<context>
    <name>PageDSL</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>Set up a dial-up network connection</source>
        <translation>Eine Einwahl-Verbindung einrichten</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Trennen</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Verbinden</translation>
    </message>
    <message>
        <source>Add PPPoE connection</source>
        <translation>PPPoE-Verbindung hinzufügen</translation>
    </message>
</context>
<context>
    <name>PageDSLSettings</name>
    <message>
        <source> Network Properties</source>
        <translation>Netzwerk-Eigenschaften</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Sind Sie sicher, dass Sie diese Einstellung löschen möchten?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
</context>
<context>
    <name>PageDetails</name>
    <message>
        <source>Network Details</source>
        <translation>Netzwerkdetails</translation>
    </message>
    <message>
        <source>View all network configurations</source>
        <translation>Alle Netzwerk-Konfigurationen zeigen</translation>
    </message>
    <message>
        <source>Details has been copied</source>
        <translation>Details wurden kopiert</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Alles auswählen</translation>
    </message>
    <message>
        <source>Network Detection</source>
        <translation>Netzwerk-Erkennung</translation>
    </message>
</context>
<context>
    <name>PageHotspot</name>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personal</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Keines</translation>
    </message>
    <message>
        <source>2.4 GHz</source>
        <translation>2,4 GHz</translation>
    </message>
    <message>
        <source>5 GHz</source>
        <translation>5 GHz</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Nicht verknüpft</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Persönlicher Hotspot</translation>
    </message>
    <message>
        <source>Share the network</source>
        <translation>Netzwerk-Verbindung weiterreichen</translation>
    </message>
    <message>
        <source>My Hotspot</source>
        <translation>Mein Hotspot</translation>
    </message>
    <message>
        <source>Edit My Hotspot</source>
        <translation>Meinen Hotspot bearbeiten</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Name (SSID)</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Erforderlich</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Sicherheit</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Band</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>Shared Settings</source>
        <translation>Weiterreich-Einstellungen</translation>
    </message>
    <message>
        <source>Hotspot Sharing Device</source>
        <translation>Hotspot-Einrichte-Gerät</translation>
    </message>
    <message>
        <source>If you want to use the personal hotspot, disable Airplane Mode first and then enable the wireless network adapter.</source>
        <translation>Wenn Sie den persönlichen Hotspot verwenden möchten, schalten sie zunächst den Flugmodus aus und dann den Drahtlosnetzwerk-Adapter ein.</translation>
    </message>
    <message>
        <source>If you want to use the personal hotspot, disable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Airplane Mode&lt;/a&gt; first and then enable the wireless network adapter.</source>
        <translation>Wenn Sie den persönlichen Hotspot verwenden möchten, schalten sie zunächst den &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Flugmodus&lt;/a&gt; aus und dann den Drahtlosnetzwerk-Adapter ein.</translation>
    </message>
</context>
<context>
    <name>PageSettings</name>
    <message>
        <source> Network Properties</source>
        <translation>Netzwerk-Eigenschaften</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Sind Sie sicher, dass Sie diese Einstellung löschen möchten?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
</context>
<context>
    <name>PageSystemProxy</name>
    <message>
        <source>System Proxy</source>
        <translation>System-Proxy</translation>
    </message>
    <message>
        <source>Set up proxy servers</source>
        <translation>Proxy-Server einrichten</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Proxy-Typ</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Selbsteingabe</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Konfigurations-URL</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Erforderlich</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP-Proxy</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS-Proxy</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>FTP-Proxy</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS-Proxy</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Die Proxy-Einstellungen für obige Hosts und Domains nicht beachten</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
</context>
<context>
    <name>PageVPN</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Connect, add, import</source>
        <translation>Verbinden, hinzufügen, importieren</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Trennen</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Verbinden</translation>
    </message>
    <message>
        <source>Add VPN</source>
        <translation>VPN hinzufügen</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>VPN importieren</translation>
    </message>
    <message>
        <source>*.conf</source>
        <translation>*.conf</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Import-Fehler</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>Datei-Fehler</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>O.K.</translation>
    </message>
</context>
<context>
    <name>PageVPNSettings</name>
    <message>
        <source> Network Properties</source>
        <translation>Netzwerk-Eigenschaften</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>VPN-Typ</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Sind Sie sicher, dass Sie diese Einstellung löschen möchten?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportieren</translation>
    </message>
    <message>
        <source>*.conf</source>
        <translation>*.conf</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
</context>
<context>
    <name>PageWiredDevice</name>
    <message>
        <source>Connect, edit network settings</source>
        <translation>Verbinden, Bearbeiten der Netzwekeinstellungen</translation>
    </message>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Zuerst das Netzwerkabel anstecken</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Trennen</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Verbinden</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Netzwerkverbindung hinzufügen</translation>
    </message>
</context>
<context>
    <name>PageWirelessDevice</name>
    <message>
        <source>Connect, edit network settings</source>
        <translation>Verbinden, Bearbeiten der Netzwekeinstellungen</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Trennen</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Verbinden</translation>
    </message>
    <message>
        <source>My&#xa0;Networks</source>
        <translation>Meine&#xa0;Netzwerke</translation>
    </message>
    <message>
        <source>Other Networks</source>
        <translation>Andere Netzwerke</translation>
    </message>
    <message>
        <source>Disable Airplane Mode first if you want to connect to a wireless network</source>
        <translation>Zuerst Flugmodus ausschalten, falls Sie sich mit einem Drahtlosnetzwerk verbinden wollen</translation>
    </message>
    <message>
        <source>Disable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>Deaktivieren Sie zuerst den &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Flugmodus&lt;/a&gt; wenn Sie sich mit einem Drahtlosnetzwerk verbinden wollen</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Zuerst Hotspot ausschalten, wenn Sie sich mit einem Drahtlosnetzwerk verbinden wollen</translation>
    </message>
    <message>
        <source>&lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;Disable hotspot&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>Zuerst &lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;Hotspot abschalten&lt;/a&gt;, wenn Sie sich mit einem Drahtlosnetzwerk verbinden wollen.</translation>
    </message>
</context>
<context>
    <name>SectionDNS</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Fertig</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Ändern</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Ungültige IP-Adresse</translation>
    </message>
</context>
<context>
    <name>SectionDevice</name>
    <message>
        <source>Not Bind</source>
        <translation>Nicht verknüpft</translation>
    </message>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Geräte-MAC-Adresse</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Geklonte MAC-Adresse</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>MTU selbst einstellen</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Band</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>2.4 GHz</source>
        <translation>2,4 GHz</translation>
    </message>
    <message>
        <source>5 GHz</source>
        <translation>5 GHz</translation>
    </message>
</context>
<context>
    <name>SectionGeneric</name>
    <message>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Name (SSID)</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Erforderlich</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Autom.-Verbinden</translation>
    </message>
</context>
<context>
    <name>SectionIPv4</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Fertig</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Ändern</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Deaktiviert</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Selbsteingabe</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Methode</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Wird nur bei korrespondierenden Quellen eingesetzt</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP-Adresse</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Ungültige IP-Adresse</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netzmaske</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished">Ungültiger Gateway</translation>
    </message>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SectionIPv6</name>
    <message>
        <source>Disabled</source>
        <translation>Deaktiviert</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Selbsteingabe</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Nicht beachten</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Fertig</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Ändern</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Methode</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Wird nur bei korrespondierenden Quellen eingesetzt</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP-Adresse</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Ungültige IP-Adresse</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Präfix</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished">Ungültiger Gateway</translation>
    </message>
</context>
<context>
    <name>SectionPPP</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>MPPE benutzen</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-bit MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stateful MPPE</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>EAP-Authentifizierung verweigern</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>PAP-Authentifizierung verweigern</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>CHAP-Authentifizierung verweigern</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>MSCHAP-Authentifizierung verweigern</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>MSCHAPv2-Authentifizierung verweigern</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Keine BSD-Datenkomprimierung</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Keine Deflate-Datenkomprimierung</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Keine TCP-Header-Komprimierung</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>PPP-Echo-Pakete senden</translation>
    </message>
</context>
<context>
    <name>SectionPPPOE</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Erforderlich</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Service</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
</context>
<context>
    <name>SectionSecret</name>
    <message>
        <source>Security</source>
        <translation>Sicherheit</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>getunneltes TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>geschütztes EAP</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>GTC</source>
        <translation>GTC</translation>
    </message>
    <message>
        <source>MSCHAPV2</source>
        <translation>MSCHAPV2</translation>
    </message>
    <message>
        <source>PAP</source>
        <translation>PAP</translation>
    </message>
    <message>
        <source>MSCHAP</source>
        <translation>MSCHAP</translation>
    </message>
    <message>
        <source>CHAP</source>
        <translation>CHAP</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Keines</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Enterprise</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personal</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAP Auth</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Identität</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Erforderlich</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>PW-Optionen</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Passwort für diesen Benutzer speichern</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Passwort für alle Benutzer speichern</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Immer rückfragen</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Schlüssel</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Privates Passwort</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Authentifizierung</translation>
    </message>
    <message>
        <source>Shared key</source>
        <translation>Geteilter Schlüssel</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>Offenes System</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privater Schlüssel</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>Anonyme ID</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Provisioning</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Deaktiviert</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Anonym</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Authentifiziert</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Beides</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>PAC-Datei</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA-Cert</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Benutzer-Cert</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>PEAP-Version</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Version 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Version 1</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Innere Auth</translation>
    </message>
</context>
<context>
    <name>SectionVPN</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>Alle Dateien (*)</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Erforderlich</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Ungültiger Gateway</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA-Cert</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Erlaube Cisco Secure Desktop Trojaner</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>CSD-Script</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Auth-Typ</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privater Schlüssel</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH-Agent</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Smart Card</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Vorverteilter Schlüssel</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Benutzer-Cert</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>FSID für die Schlüsselphrase verwenden</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Zertifikate (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Zertifikate mit Passwort (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Statischer Schlüssel</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>PW-Optionen</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Gespeichert</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Anfrage</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Nicht erforderlich</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Privates Passwort</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Schlüssel-Richtung bestimmen</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Schlüssel-Richtung</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>Fern-IP</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>Lokale IP</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>NT Domain</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Eine Innere IP-Adresse abfragen</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>UDP-Abkapselung erzwingen</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>IP-Komprimierung verwenden</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>Ermögliche eigene Cipher-Vorschläge</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Gruppenname</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Gruppenpasswort</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Hybride Authentifizierung benutzen</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>CA-Datei</translation>
    </message>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>MPPE benutzen</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Sicherheit</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Alle Verfügbaren (voreingestellt)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-bit (weniger sicher)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-bit (am sichersten)</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stateful MPPE</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>EAP-Authentifizierung verweigern</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>PAP-Authentifizierung verweigern</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>CHAP-Authentifizierung verweigern</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>MSCHAP-Authentifizierung verweigern</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>MSCHAPv2-Authentifizierung verweigern</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Keine BSD-Datenkomprimierung</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Keine Deflate-Datenkomprimierung</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Keine TCP-Header-Komprimierung</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Keine Protokollfeld-Komprimierung</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Keine Adress-/Kontroll-Komprimierung</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>PPP-Echo-Pakete senden</translation>
    </message>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>Ermögliche IPsec</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>Gruppen-ID</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Phase1-Algorithmen</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Phase2-Algorithmen</translation>
    </message>
    <message>
        <source>VPN Advanced</source>
        <translation>Erweitertes VPN</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Gateway-Port bestimmen</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Gateway Port</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Wiederauffrischungsinterval bestimmen</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Wiederauffrischungsinterval</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>LZO-Daten-Kompression verwenden</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>TCP-Verbindung verwenden</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>TAP-Gerät verwenden</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Tunnel MTU festlegen</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>UDP-Fragment-Größe bestimmen</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>UDP-Fragment-Größe</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Tunnel TCP MSS verbieten</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>zufällige Fernzugriffs-Hosts</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Domain</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Hersteller</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (voreingestellt)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Verschlüsselung</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Sicher (voreingestellt)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Schwach</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Keine</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>NAT Traversal-Modus</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T falls verfügbar (voreingestellt)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>NAT-T Immer</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Ausgeschaltet</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>IKE DH Gruppe</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH Gruppe 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH Gruppe 2 (voreingestellt)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH Gruppe 5</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Forward Secrecy</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Server (voreingestellt)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH Gruppe 2</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Lokaler Port</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Tote Peer-Feststellung ausschalten</translation>
    </message>
    <message>
        <source>VPN Security</source>
        <translation>VPN-Sicherheit</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Cipher</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Voreingestellt</translation>
    </message>
    <message>
        <source>DES-CBC</source>
        <translation>DES-CBC</translation>
    </message>
    <message>
        <source>RC2-CBC</source>
        <translation>RC2-CBC</translation>
    </message>
    <message>
        <source>DES-EDE-CBC</source>
        <translation>DES-EDE-CBC</translation>
    </message>
    <message>
        <source>DES-EDE3-CBC</source>
        <translation>DES-EDE3-CBC</translation>
    </message>
    <message>
        <source>DESX-CBC</source>
        <translation>DESX-CBC</translation>
    </message>
    <message>
        <source>BF-CBC</source>
        <translation>BF-CBC</translation>
    </message>
    <message>
        <source>RC2-40-CBC</source>
        <translation>RC2-40-CBC</translation>
    </message>
    <message>
        <source>CAST5-CBC</source>
        <translation>CAST5-CBC</translation>
    </message>
    <message>
        <source>RC2-64-CBC</source>
        <translation>RC2-64-CBC</translation>
    </message>
    <message>
        <source>AES-128-CBC</source>
        <translation>AES-128-CBC</translation>
    </message>
    <message>
        <source>AES-192-CBC</source>
        <translation>AES-192-CBC</translation>
    </message>
    <message>
        <source>AES-256-CBC</source>
        <translation>AES-256-CBC</translation>
    </message>
    <message>
        <source>CAMELLIA-128-CBC</source>
        <translation>CAMELLIA-128-CBC</translation>
    </message>
    <message>
        <source>CAMELLIA-192-CBC</source>
        <translation>CAMELLIA-192-CBC</translation>
    </message>
    <message>
        <source>CAMELLIA-256-CBC</source>
        <translation>CAMELLIA-256-CBC</translation>
    </message>
    <message>
        <source>SEED-CBC</source>
        <translation>SEED-CBC</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC Auth</translation>
    </message>
    <message>
        <source>RSA MD-4</source>
        <translation>RSA MD-4</translation>
    </message>
    <message>
        <source>MD-5</source>
        <translation>MD-5</translation>
    </message>
    <message>
        <source>SHA-1</source>
        <translation>SHA-1</translation>
    </message>
    <message>
        <source>SHA-224</source>
        <translation>SHA-224</translation>
    </message>
    <message>
        <source>SHA-256</source>
        <translation>SHA-256</translation>
    </message>
    <message>
        <source>SHA-384</source>
        <translation>SHA-384</translation>
    </message>
    <message>
        <source>SHA-512</source>
        <translation>SHA-512</translation>
    </message>
    <message>
        <source>RIPEMD-160</source>
        <translation>RIPEMD-160</translation>
    </message>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN Proxy</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Proxy-Typ</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>Server-IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Endlos weiter versuchen, falls fehlgeschlagen</translation>
    </message>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>VPN TLS Authentifizierung</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Subjekt-Übereinstimmung</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Fernzugriffs-Cert-Typ</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Client</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Server</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Schlüssel-Datei</translation>
    </message>
</context>
<context>
    <name>SystemProxyConfigItem</name>
    <message>
        <source>Optional</source>
        <translation>Optional</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Authentication is required</source>
        <translation>Authentifizierung erforderlich</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Erforderlich</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
</context>
<context>
    <name>dde::network::NetAirplaneModeTipsItem</name>
    <message>
        <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>Deaktivieren Sie zuerst den &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Flugmodus&lt;/a&gt;, um sich mit einem Drahtlos-Netzwerk verbinden zu können</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerPrivate</name>
    <message>
        <source>IP conflict</source>
        <translation>IP-Konflikt</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Netzwerk</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerThreadPrivate</name>
    <message>
        <source>Wired Connection %1</source>
        <translation>Kabelverbindung %1</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>PPPoE-Verbindung %1</translation>
    </message>
    <message>
        <source>Connecting &quot;%1&quot;</source>
        <translation>Verbinde &quot;%1&quot;</translation>
    </message>
    <message>
        <source>&quot;%1&quot; connected</source>
        <translation>&quot;%1&quot; verbunden</translation>
    </message>
    <message>
        <source>&quot;%1&quot; disconnected</source>
        <translation>&quot;%1&quot; getrennt</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
        <translation>Verbindung mit %1 konnte nicht hergestellt werden, bitte überprüfen Sie Router oder Netzwerkkabel.</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
        <translation>Verbindung mit %1 konnte nicht hergestellt werden, bitte gehen Sie näher an den WLAN-Router heran.</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
        <translation>Verbindung mit %1 fehlgeschlagen, falsches Passwort</translation>
    </message>
    <message>
        <source>Password is required to connect &quot;%1&quot;</source>
        <translation>Verbindung mit &quot;%1&quot; erfordert Passwort</translation>
    </message>
    <message>
        <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
        <translation>Das &quot;%1&quot; 802.11 WLAN-Netzwerk konnte nicht gefunden werden</translation>
    </message>
    <message>
        <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
        <translation>Um sich mit %1 zu verbinden, richten Sie bitte ihre Authentifizierungs-Info nachdem Einloggen ein</translation>
    </message>
</context>
<context>
    <name>dde::network::NetSystemProxyControlItem</name>
    <message>
        <source>System Proxy</source>
        <translation>System-Proxy</translation>
    </message>
</context>
<context>
    <name>dde::network::NetVPNTipsItem</name>
    <message>
        <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
        <translation>VPN Konfiguration ist nicht verbunden oder fehlgeschlagen. Bitte &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;gehen Sie zum Kontrollzentrum&lt;/a&gt; zum Überprüfen.</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWiredControlItem</name>
    <message>
        <source>Wired Network</source>
        <translation>Kabelgebundenes Netzwerk</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessControlItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Drahtlosnetzwerk</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessHiddenItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Mit verstecktem Netzwerk verbinden</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessMineItem</name>
    <message>
        <source>My Networks</source>
        <translation>Meine Netzwerke</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessOtherItem</name>
    <message>
        <source>Other Networks</source>
        <translation>Andere Netzwerke</translation>
    </message>
</context>
<context>
    <name>network</name>
    <message>
        <source>Network</source>
        <translation>Netzwerk</translation>
    </message>
</context>
</TS>
